@@ -1,5 +1,5 @@
 // Package json is a JSON parser following the specifications at http://json.org/.
-package json // import "github.com/tdewolff/parse/json"
+package json
 
 import (
 	"io"
@@ -117,7 +117,7 @@ func (p *Parser) Next() (GrammarType, []byte) {
 	state := p.state[len(p.state)-1]
 	if c == ',' {
 		if state != ArrayState && state != ObjectKeyState {
-			p.err = parse.NewErrorLexer("unexpected comma character outside an array or object", p.r)
+			p.err = parse.NewErrorLexer("unexpected comma character", p.r)
 			return ErrorGrammar, nil
 		}
 		p.r.Move(1)
@@ -188,7 +188,15 @@ func (p *Parser) Next() (GrammarType, []byte) {
 		} else if p.consumeLiteralToken() {
 			return LiteralGrammar, p.r.Shift()
 		}
+		c := p.r.Peek(0) // pick up movement from consumeStringToken to detect NULL or EOF
+		if c == 0 && p.r.Err() == nil {
+			p.err = parse.NewErrorLexer("unexpected NULL character", p.r)
+			return ErrorGrammar, nil
+		} else if c == 0 { // EOF
+			return ErrorGrammar, nil
+		}
 	}
+	p.err = parse.NewErrorLexer("unexpected character", p.r)
 	return ErrorGrammar, nil
 }
 
